using System;
using System.Collections.Generic;
using System.Linq;
using Styx;
using Styx.WoWInternals;
using Styx.WoWInternals.WoWObjects;
using Styx.Plugins.PluginClass;
using Styx.Logic;

namespace PushNotify 
{
    public partial class PushNotify : HBPlugin 
    {
        #region Player Events
        void Player_OnLevelUp(BotEvents.Player.LevelUpEventArgs args) 
        {
            if (args.NewLevel == 0)
                return;
            if (Instance.Settings.PushLevelUp)
                AddNotificationToQueue(String.Format("{1} is now level {0}", args.NewLevel, Me.Name), "Level Up !", NMA.NMANotificationPriority.Moderate);
        }
        void Player_OnPlayerDied() 
        {
            if (String.IsNullOrEmpty(Me.ZoneText))
                return;
            if (Instance.Settings.PushDead)
                AddNotificationToQueue(String.Format("{1} died in {0}", Me.SubZoneText, Me.Name), "You died !", NMA.NMANotificationPriority.Moderate);
        }
        void HandleArcheology(object sender, LuaEventArgs args)
        {
            object[] Args = args.Args;
            string message = Args[0].ToString();
            dLog("Archeology Solve Detected: " + message);
            if (Instance.Settings.PushArchSolve)
                AddNotificationToQueue("Just solved: " + message, String.Format("Archeology Buddy"), NMA.NMANotificationPriority.Moderate);
        }
        void LootsFilter(List<WoWObject> incomingUnits, HashSet<WoWObject> outgoingUnits)
        {
            if (StyxWoW.Me.GotTarget && StyxWoW.Me.CurrentTarget.Level < Instance.LootLevel && PushNotify.UseLootFilter)
            {
                Styx.Logic.Blacklist.Add(StyxWoW.Me.CurrentTarget.Guid, TimeSpan.FromMinutes(15));
                outgoingUnits.Remove(StyxWoW.Me.CurrentTarget);
                if (!StyxWoW.Me.CurrentTarget.IsAlive)
                {
                    Styx.StyxWoW.Me.ClearTarget();
                }
            }
        }
        void CheckAndBlackList(Styx.BotEvents.Player.MobKilledEventArgs arg)
        {
            if (arg.KilledMob.Level < Instance.LootLevel)
            {
                // Used only to put message in log
                if (PushNotify.UseLootFilter)
                {
                    Log("Not looting level " + arg.KilledMob.Level.ToString() + " " + arg.KilledMob.Name.ToString());
                }
            }
        }
        #endregion

        #region Chat Events
        void HandleBNWhisper(object sender, LuaEventArgs args) 
        {
            object[] Args = args.Args;
            string message = Args[0].ToString();
            string presenceId = Args[12].ToString();
            string senderName = Lua.GetReturnValues(String.Format("return BNGetFriendInfoByID({0})", presenceId))[3];
            if (Instance.Settings.PushBNWhisper)
                AddNotificationToQueue("[" + senderName + "] " + message, String.Format("New BattleNet message to {0}", Me.Name), NMA.NMANotificationPriority.Moderate);
        }
        void WoWChat_Yell(WoWChat.ChatLanguageSpecificEventArgs e)
        {
            UpdateAliases();
            string sender = e.Author;
//          if (sender == Me.Name)
//              return;
            string message = e.Message;
            string time = DateTime.Now.ToString();
            if (Instance.Settings.PushYellOnlyMe)
            {
                var words = e.Message.Split(new string[] { " " }, StringSplitOptions.RemoveEmptyEntries);
                if (!words.Any(a => _names.Contains(a.ToLower()) || _aliases.Contains(a.ToLower())))
                    return;
                dLog("Targeted yell message: [" + sender + "] " + message);
                AddNotificationToQueue("[" + sender + "] " + message, String.Format("Targeted yell message to {0}", Me.Name), NMA.NMANotificationPriority.High);
            }
            else
            {
                dLog("Received yell: [" + sender + "] " + message);
                if (Instance.Settings.PushYell)
                    AddNotificationToQueue("[" + sender + "] " + message, String.Format("Yell message detected!", Me.Name), NMA.NMANotificationPriority.Moderate);
            }
        }        
        void WoWChat_TextEmote(WoWChat.ChatAuthoredEventArgs e) 
        {
            string sender = e.Author;
            if (sender == Me.Name)
                return;
            string message = e.Message;
            string time = DateTime.Now.ToString();
            dLog("Received text emote: [" + sender + "] " + message);
            if (Instance.Settings.PushTextEmote)
                AddNotificationToQueue("[" + sender + "] " + message, String.Format("New text emote to {0}", Me.Name), NMA.NMANotificationPriority.Moderate);
        }
        void WoWChat_Say(WoWChat.ChatLanguageSpecificEventArgs e) 
        {
            UpdateAliases();
            string sender = e.Author;
//          if (sender == Me.Name)
//              return;
            string message = e.Message;
            string time = DateTime.Now.ToString();
            if (Instance.Settings.PushSayOnlyMe) 
            {
                var words = e.Message.Split(new string[] { " " }, StringSplitOptions.RemoveEmptyEntries);
                if (!words.Any(a => _names.Contains(a.ToLower()) || _aliases.Contains(a.ToLower())))
                    return;
                dLog("Targeted say message: [" + sender + "] " + message);
                AddNotificationToQueue("[" + sender + "] " + message, String.Format("Targeted say message to {0}", Me.Name), NMA.NMANotificationPriority.High);
            } else
            {
                dLog("General say message: [" + sender + "] " + message);
                if (Instance.Settings.PushSay)
                    AddNotificationToQueue("[" + sender + "] " + message, String.Format("General say message detected!", Me.Name), NMA.NMANotificationPriority.Moderate);
            }
        }
        void WoWChat_Party(WoWChat.ChatLanguageSpecificEventArgs e) 
        {
            UpdateAliases();
            string sender = e.Author;
//          if (sender == Me.Name)
//              return;
            string message = e.Message;
            string time = DateTime.Now.ToString();
            if (Instance.Settings.PushPartyOnlyMe) 
            {
                var words = e.Message.Split(new string[] { " " }, StringSplitOptions.RemoveEmptyEntries);
                if (!words.Any(a => _names.Contains(a.ToLower()) || _aliases.Contains(a.ToLower())))
                    return;
                dLog("Targeted party message: [" + sender + "] " + message);
                AddNotificationToQueue("[" + sender + "] " + message, String.Format("Targeted party message to {0}", Me.Name), NMA.NMANotificationPriority.High);
            } else
            {
                dLog("General party message: [" + sender + "] " + message);
                if (Instance.Settings.PushParty)
                    AddNotificationToQueue("[" + sender + "] " + message, String.Format("General party message detected!", Me.Name), NMA.NMANotificationPriority.Moderate);
            }
        }
        void WoWChat_PartyLeader(WoWChat.ChatLanguageSpecificEventArgs e)
        {
            UpdateAliases();
            string sender = e.Author;
//          if (sender == Me.Name)
//              return;
            string message = e.Message;
            string time = DateTime.Now.ToString();
            if (Instance.Settings.PushPartyOnlyMe) 
            {
                var words = e.Message.Split(new string[] { " " }, StringSplitOptions.RemoveEmptyEntries);
                if (!words.Any(a => _names.Contains(a.ToLower()) || _aliases.Contains(a.ToLower())))
                    return;
                dLog("Targeted party message: [" + sender + "] " + message);
                AddNotificationToQueue("[" + sender + "] " + message, String.Format("Targeted party message to {0}", Me.Name), NMA.NMANotificationPriority.High);
            } else 
            {
                dLog("General party message: [" + sender + "] " + message);
                if (Instance.Settings.PushParty)
                    AddNotificationToQueue("[" + sender + "] " + message, String.Format("General party message detected!", Me.Name), NMA.NMANotificationPriority.Moderate);
            }
        }
        void WoWChat_Guild(WoWChat.ChatGuildEventArgs e)
        {
            UpdateAliases();
            string sender = e.Author;
//          if (sender == Me.Name)
//              return;
            string message = e.Message;
            string time = DateTime.Now.ToString();
            if (Instance.Settings.PushGuildOnlyMe)
            {
                var words = e.Message.Split(new string[] { " " }, StringSplitOptions.RemoveEmptyEntries);
                if (!words.Any(a => _names.Contains(a.ToLower()) || _aliases.Contains(a.ToLower())))
                    return;
                dLog("Targeted guild message: [" + sender + "] " + message);
                AddNotificationToQueue("[" + sender + "] " + message, String.Format("Targeted guild message to {0}", Me.Name), NMA.NMANotificationPriority.High);
            } else 
            {
                dLog("General guild message: [" + sender + "] " + message);
                if (Instance.Settings.PushGuild)
                    AddNotificationToQueue("[" + sender + "] " + message, String.Format("General guild message detected!", Me.Name), NMA.NMANotificationPriority.Moderate);
            }
        }
        void WoWChat_Emote(WoWChat.ChatAuthoredEventArgs e) 
        {
            string sender = e.Author;
//          if (sender == Me.Name)
//              return;
            string message = e.Message;
            string time = DateTime.Now.ToString();
            dLog("Received emote: [" + sender + "] " + message);
            if (Instance.Settings.PushEmote)
                AddNotificationToQueue("[" + sender + "] " + message, String.Format("New emote to {0}", Me.Name), NMA.NMANotificationPriority.Moderate);
        }
        void WoWChat_Battleground(WoWChat.ChatLanguageSpecificEventArgs e) 
        {
            UpdateAliases();
            string sender = e.Author;
//          if (sender == Me.Name)
//              return;
            string message = e.Message;
            string time = DateTime.Now.ToString();
            if (Instance.Settings.PushBattlegroundOnlyMe)
            {
                var words = e.Message.Split(new string[] { " " }, StringSplitOptions.RemoveEmptyEntries);
                if (!words.Any(a => _names.Contains(a.ToLower()) || _aliases.Contains(a.ToLower())))
                    return;
                dLog("Targeted battleground message: [" + sender + "] " + message);
                AddNotificationToQueue("[" + sender + "] " + message, String.Format("Targeted battleground to {0}", Me.Name), NMA.NMANotificationPriority.High);
            }
            else
            {
                dLog("Received battleground message: [" + sender + "] " + message);
                if (Instance.Settings.PushBattleground)
                    AddNotificationToQueue("[" + sender + "] " + message, String.Format("New battleground message detected!", Me.Name), NMA.NMANotificationPriority.Moderate);
            }
        }
        void WoWChat_Whisper(WoWChat.ChatWhisperEventArgs e) 
        {
            string sender = e.Author;
//          if (sender == Me.Name)
//              return;
            string message = e.Message;
            string time = DateTime.Now.ToString();
            dLog("Received whisper: [" + sender + "] " + message);
            if (Instance.Settings.PushWhisper)
                AddNotificationToQueue("[" + sender + "] " + message, String.Format("New whisper to {0}", Me.Name), NMA.NMANotificationPriority.Moderate);
        }
        #endregion
    }
}
