using System;
using System.Collections.Specialized;
using System.Drawing;
using System.IO;
using System.Linq;
using System.Net;
using System.Text;
using System.Web;
using Styx.Helpers;
using Styx.WoWInternals;


namespace PushNotify 
{
    public partial class PushNotify 
    {
        #region Log Methods
        public static void Log(string format, params object[] args) 
        {
            Log(Color.Yellow, format, args);
        }
        public static void Log(Color color, string format, params object[] args) 
        {
            Logging.Write(color, "[PushNotify]: " + format, args);
        }
        public static void dLog(string format, params object[] args) {
            Logging.WriteDebug(Color.Yellow, "[PushNotify]: " + format, args);
        }
        public static void eLog(Exception ex) 
        {
            Logging.WriteException(Color.DarkRed, ex);
        }
        #endregion
      
        #region Push Notifications
        private struct Notification 
        {
            public string Event { get; set; }
            public string Description { get; set; }
            public NMA.NMANotificationPriority Priority { get; set; }
        }
        private static void AddNotificationToQueue(string description, string eventName, NMA.NMANotificationPriority priority) 
        {
            var newNotification =
                new Notification 
                {
                    Description = description,
                    Event = eventName,
                    Priority = priority
                };
            pushQueue.Enqueue(newNotification);
        }
        private static void SendNotification(Notification notification) 
        {
            if (Instance.Settings.UseNMA && !String.IsNullOrEmpty(Instance.Settings.NMAAPIKEY)) 
            {
                var newNotification =
                    new NMA.NMANotification {
                        Description = notification.Description,
                        Event = notification.Event,
                        Priority = notification.Priority
                    };
                var newClient = new NMA.NMA();
                dLog("Sending NMA notification");
                newClient.PostNotification(newNotification);
            }
        }
        #endregion
    
        #region Generate TimeSpan from hours
        private static string GenTimeSpanFromHours(float hours) 
        {
            TimeSpan interval = TimeSpan.FromHours(hours);
            return TimeSpanToString(interval);
        }
        private static string TimeSpanToString(TimeSpan time) 
        {
            return time.Hours + "h " + time.Minutes + "m " + time.Seconds + "s";
        }
        #endregion
      
        #region RealmName
        private static string RealmName 
        {
            get 
            {
                return Lua.GetReturnVal<string>("return GetRealmName()", 0).Replace("'", "");
            }
        }
        #endregion
      
        #region TimeToLevel
        private static string TimeToLevel 
        {
            get 
            {
                uint xpLeft = Me.NextLevelExperience - Me.Experience;
                if (xpLeft == 0 || InfoPanel.XPPerHour == 0)
                    return "0";
                return GenTimeSpanFromHours(xpLeft / InfoPanel.XPPerHour);
            }
        }
        #endregion
        
        #region UpdateAliases
        private static void UpdateAliases()
        {   
            PushNotify.Instance._aliases.Clear();
            PushNotify.Instance._aliases.Insert(0, PushNotify.Instance.Settings.PushAlias1.ToLower());
            PushNotify.Instance._aliases.Insert(1, PushNotify.Instance.Settings.PushAlias2.ToLower());
            PushNotify.Instance._aliases.Insert(2, PushNotify.Instance.Settings.PushAlias3.ToLower());
            PushNotify.Instance._aliases.Insert(3, PushNotify.Instance.Settings.PushAlias4.ToLower());
            PushNotify.Instance._aliases.Insert(4, PushNotify.Instance.Settings.PushAlias5.ToLower());
            PushNotify.Instance._aliases.Insert(5, PushNotify.Instance.Settings.PushAlias6.ToLower());
            PushNotify.Instance._aliases.Insert(6, PushNotify.Instance.Settings.PushAlias7.ToLower());
            PushNotify.Instance._aliases.Insert(7, PushNotify.Instance.Settings.PushAlias8.ToLower());
            PushNotify.Instance._aliases.Insert(8, PushNotify.Instance.Settings.PushAlias9.ToLower());
            PushNotify.Instance._aliases.Insert(9, PushNotify.Instance.Settings.PushAlias10.ToLower());
        }
        #endregion

        #region CheckLootlevel
        private static void CheckLootlevel()
        {
            if (!UseLootFilter && PushNotify.Instance.Settings.UseLootFilter)
            {
                Log("Mob Level LootFilter is Enabled.");
                UseLootFilter = PushNotify.Instance.Settings.UseLootFilter;
            }

            if (UseLootFilter && !PushNotify.Instance.Settings.UseLootFilter)
            {
                Log("Mob Level LootFilter is Disabled.");
                UseLootFilter = PushNotify.Instance.Settings.UseLootFilter;
            }

            if (PushNotify.UseLootFilter)
            {
                if (PushNotify.Instance.LootLevel != PushNotify.Me.Level - PushNotify.Instance.Settings.LootFilterOffset)
                {
                    PushNotify.Instance.LootLevel = (PushNotify.Me.Level - PushNotify.Instance.Settings.LootFilterOffset);
                    Log("Bot should not loot mobs below level " + (PushNotify.Me.Level - Instance.Settings.LootFilterOffset).ToString());
                }
            }
        }
        #endregion
    }
}
