// By Casey Watson
// http://www.caseywatson.com/

using System;
using System.Configuration;
using System.Net;
using System.Text;
using System.Web;

namespace PushNotify.NMA 
{
    public class NMA 
    {
        private const string CLIENT_CONFIG_SECTION_NAME = "NMAClient";
        private const string EX_MSG_CLIENT_CONFIG_SECTION_NOT_FOUND =
            "NMA client configuration section [{0}] not found; unable to proceed.";
        private const string POST_NOTIFICATION_BASE_METHOD = 
            "?apikey={0}&application={1}&description={2}&event={3}&priority={4}";
        private const string REQUEST_CONTENT_TYPE = "application/x-www-form-urlencoded";
        private const string REQUEST_METHOD_TYPE = "POST";

		public NMA() { }
	
		public void PostNotification(NMANotification notification_) 
        {
            var updateRequest = 
                HttpWebRequest.Create(BuildNotificationRequestUrl(notification_)) as HttpWebRequest;
            updateRequest.ContentLength = 0;
            updateRequest.ContentType = REQUEST_CONTENT_TYPE;
            updateRequest.Method = REQUEST_METHOD_TYPE;
            updateRequest.Timeout = 5000;
            
            var postResponse = default(WebResponse);
            try 
            {
                postResponse = updateRequest.GetResponse();
            } finally 
            {
                if (postResponse != null)
                    postResponse.Close();
            }
        }
        
        private string BuildNotificationRequestUrl(NMANotification notification_) 
        {
            var NMAUrlSb = new StringBuilder(@"https://www.notifymyandroid.com/publicapi/notify");
            
            NMAUrlSb.AppendFormat(
                POST_NOTIFICATION_BASE_METHOD,
                HttpUtility.UrlEncode(PushNotify.Instance.Settings.NMAAPIKEY),
                HttpUtility.UrlEncode("PushNotify"),
                HttpUtility.UrlEncode(notification_.Description),
                HttpUtility.UrlEncode(notification_.Event),
                ((sbyte)(notification_.Priority)));
            return NMAUrlSb.ToString();
        }
    }

    public struct NMANotification 
    {
        public string Event { get; set; }
        public string Description { get; set; }
        public NMANotificationPriority Priority { get; set; }
    }
    public enum NMANotificationPriority : sbyte 
    {
        VeryLow = -2,
        Moderate = -1,
        Normal = 0,
        High = 1,
        Emergency = 2
    }
}
